@@ -1,33 +1,36 @@
 
 from __future__ import print_function
 
-import os
+import signal
 import sys
 import pyuv
 
-if sys.version_info >= (3, 0):
-    LINESEP = os.linesep.encode()
-else:
-    LINESEP = os.linesep
 
 def on_tty_read(handle, data, error):
-    data = data.strip()
-    if data == b"exit":
+    if data is None or data == b"exit":
         tty_stdin.close()
         tty_stdout.close()
     else:
-        tty_stdout.write(data+LINESEP)
+        tty_stdout.write(data)
+
+def signal_cb(handle, signum):
+    tty_stdin.close()
+    tty_stdout.close()
+    signal_h.close()
+
 
 loop = pyuv.Loop.default_loop()
 
-tty_stdin = pyuv.TTY(loop, sys.stdin.fileno())
+tty_stdin = pyuv.TTY(loop, sys.stdin.fileno(), True)
 tty_stdin.start_read(on_tty_read)
-
-tty_stdout = pyuv.TTY(loop, sys.stdout.fileno())
+tty_stdout = pyuv.TTY(loop, sys.stdout.fileno(), False)
 
 if sys.platform != "win32":
     print("Window size: (%d, %d)" % tty_stdin.get_winsize())
 
+signal_h = pyuv.Signal(loop)
+signal_h.start(signal_cb, signal.SIGINT)
+
 loop.run()
 
 pyuv.TTY.reset_mode()
