@@ -122,7 +122,7 @@ static PyObject *
 UDP_func_bind(UDP *self, PyObject *args)
 {
     int r, flags;
-    struct sockaddr sa;
+    struct sockaddr_storage ss;
     PyObject *addr;
 
     RAISE_IF_HANDLE_NOT_INITIALIZED(self, NULL);
@@ -134,15 +134,15 @@ UDP_func_bind(UDP *self, PyObject *args)
         return NULL;
     }
 
-    if (pyuv_parse_addr_tuple(addr, &sa) < 0) {
+    if (pyuv_parse_addr_tuple(addr, &ss) < 0) {
         /* Error is set by the function itself */
         return NULL;
     }
 
-    if (sa.sa_family == AF_INET) {
-        r = uv_udp_bind(&self->udp_h, *(struct sockaddr_in *)&sa, flags);
+    if (ss.ss_family == AF_INET) {
+        r = uv_udp_bind(&self->udp_h, *(struct sockaddr_in *)&ss, flags);
     } else {
-        r = uv_udp_bind6(&self->udp_h, *(struct sockaddr_in6 *)&sa, flags);
+        r = uv_udp_bind6(&self->udp_h, *(struct sockaddr_in6 *)&ss, flags);
     }
 
     if (r != 0) {
@@ -214,7 +214,7 @@ static PyObject *
 UDP_func_send(UDP *self, PyObject *args)
 {
     int r;
-    struct sockaddr sa;
+    struct sockaddr_storage ss;
     uv_buf_t buf;
     Py_buffer *view;
     PyObject *addr, *callback;
@@ -243,7 +243,7 @@ UDP_func_send(UDP *self, PyObject *args)
         goto error;
     }
 
-    if (pyuv_parse_addr_tuple(addr, &sa) < 0) {
+    if (pyuv_parse_addr_tuple(addr, &ss) < 0) {
         /* Error is set by the function itself */
         goto error;
     }
@@ -255,10 +255,10 @@ UDP_func_send(UDP *self, PyObject *args)
     ctx->view_count = 1;
     ctx->views = view;
 
-    if (sa.sa_family == AF_INET) {
-        r = uv_udp_send(&ctx->req, &self->udp_h, &buf, 1, *(struct sockaddr_in *)&sa, (uv_udp_send_cb)on_udp_send);
+    if (ss.ss_family == AF_INET) {
+        r = uv_udp_send(&ctx->req, &self->udp_h, &buf, 1, *(struct sockaddr_in *)&ss, (uv_udp_send_cb)on_udp_send);
     } else {
-        r = uv_udp_send6(&ctx->req, &self->udp_h, &buf, 1, *(struct sockaddr_in6 *)&sa, (uv_udp_send_cb)on_udp_send);
+        r = uv_udp_send6(&ctx->req, &self->udp_h, &buf, 1, *(struct sockaddr_in6 *)&ss, (uv_udp_send_cb)on_udp_send);
     }
     if (r != 0) {
         RAISE_UV_EXCEPTION(UV_HANDLE_LOOP(self), PyExc_UDPError);
@@ -282,7 +282,7 @@ static PyObject *
 UDP_func_sendlines(UDP *self, PyObject *args)
 {
     int i, r, buf_count;
-    struct sockaddr sa;
+    struct sockaddr_storage ss;
     PyObject *addr, *callback, *seq;
     Py_buffer *views;
     uv_buf_t *bufs;
@@ -303,7 +303,7 @@ UDP_func_sendlines(UDP *self, PyObject *args)
         return NULL;
     }
 
-    if (pyuv_parse_addr_tuple(addr, &sa) < 0) {
+    if (pyuv_parse_addr_tuple(addr, &ss) < 0) {
         /* Error is set by the function itself */
         return NULL;
     }
@@ -326,10 +326,10 @@ UDP_func_sendlines(UDP *self, PyObject *args)
     ctx->view_count = buf_count;
     ctx->views = views;
 
-    if (sa.sa_family == AF_INET) {
-        r = uv_udp_send(&ctx->req, &self->udp_h, bufs, buf_count, *(struct sockaddr_in *)&sa, (uv_udp_send_cb)on_udp_send);
+    if (ss.ss_family == AF_INET) {
+        r = uv_udp_send(&ctx->req, &self->udp_h, bufs, buf_count, *(struct sockaddr_in *)&ss, (uv_udp_send_cb)on_udp_send);
     } else {
-        r = uv_udp_send6(&ctx->req, &self->udp_h, bufs, buf_count, *(struct sockaddr_in6 *)&sa, (uv_udp_send_cb)on_udp_send);
+        r = uv_udp_send6(&ctx->req, &self->udp_h, bufs, buf_count, *(struct sockaddr_in6 *)&ss, (uv_udp_send_cb)on_udp_send);
     }
 
     /* uv_write copies the uv_buf_t structures, so we can free them now */
