@@ -1,5 +1,6 @@
 
 import functools
+import sys
 import threading
 import time
 
@@ -7,30 +8,45 @@ from common import unittest2
 import pyuv
 
 
+class WorkItem(object):
+
+    def __init__(self, func, *args, **kw):
+        self._cb = functools.partial(func, *args, **kw)
+        self.result = None
+        self.exc_info = None
+
+    def __call__(self):
+        try:
+            self._cb()
+        except Exception:
+            self.exc_info = sys.exc_info()
+        finally:
+            self._cb = None
+
+
 class ThreadPoolTest(unittest2.TestCase):
 
     def setUp(self):
         self.pool_cb_called = 0
         self.pool_after_work_cb_called = 0
         self.loop = pyuv.Loop.default_loop()
-        self.pool = pyuv.ThreadPool(self.loop)
 
     def run_in_pool(self, *args, **kw):
         self.pool_cb_called += 1
         time.sleep(0.1)
 
-    def after_work_cb(self, result, error):
+    def after_work_cb(self, error):
         self.assertEqual(error, None)
         self.pool_after_work_cb_called += 1
 
     def test_threadpool1(self):
-        self.pool.queue_work(self.run_in_pool, self.after_work_cb)
+        self.loop.queue_work(self.run_in_pool, self.after_work_cb)
         args = (1, 2, 3)
         kw = {}
-        self.pool.queue_work(functools.partial(self.run_in_pool, *args, **kw), self.after_work_cb)
+        self.loop.queue_work(functools.partial(self.run_in_pool, *args, **kw), self.after_work_cb)
         args = ()
         kw = {'test': 1}
-        self.pool.queue_work(functools.partial(self.run_in_pool, *args, **kw), self.after_work_cb)
+        self.loop.queue_work(functools.partial(self.run_in_pool, *args, **kw), self.after_work_cb)
         self.loop.run()
         self.assertEqual(self.pool_cb_called, 3)
         self.assertEqual(self.pool_after_work_cb_called, 3)
@@ -38,11 +54,13 @@ class ThreadPoolTest(unittest2.TestCase):
     def raise_in_pool(self, *args, **kw):
         1/0
 
-    def after_work_cb2(self, result, error):
-        self.assertEqual(error[0], ZeroDivisionError)
+    def after_work_cb2(self, error):
+        self.assertEqual(error, None)
+        self.assertEqual(self.work_item.exc_info[0], ZeroDivisionError)
 
-    def test_threadpool2(self):
-        self.pool.queue_work(self.raise_in_pool, self.after_work_cb2)
+    def test_threadpool_exc(self):
+        self.work_item = WorkItem(self.raise_in_pool)
+        self.loop.queue_work(self.work_item, self.after_work_cb2)
         self.loop.run()
 
 
@@ -59,8 +77,7 @@ class ThreadPoolMultiLoopTest(unittest2.TestCase):
 
     def run_loop(self):
         loop = pyuv.Loop()
-        pool = pyuv.ThreadPool(loop)
-        pool.queue_work(self.run_in_pool)
+        loop.queue_work(self.run_in_pool)
         loop.run()
 
     def test_threadpool_multiple_loops(self):
@@ -72,29 +89,6 @@ class ThreadPoolMultiLoopTest(unittest2.TestCase):
         self.assertEqual(self.pool_cb_called, 3)
 
 
-class ThreadPoolThreadCount(unittest2.TestCase):
-
-    def setUp(self):
-        self.loop = pyuv.Loop.default_loop()
-        self.pool = pyuv.ThreadPool(self.loop)
-
-    def run_in_pool(self):
-        time.sleep(0.1)
-
-    def test_threadpool_thread_count(self):
-        self.pool.set_parallel_threads(10)
-        self.pool.queue_work(self.run_in_pool)
-        self.pool.queue_work(self.run_in_pool)
-        self.pool.queue_work(self.run_in_pool)
-        self.pool.queue_work(self.run_in_pool)
-        self.pool.queue_work(self.run_in_pool)
-        self.pool.queue_work(self.run_in_pool)
-        self.pool.queue_work(self.run_in_pool)
-        self.pool.queue_work(self.run_in_pool)
-        self.pool.queue_work(self.run_in_pool)
-        self.loop.run()
-
-
 if __name__ == '__main__':
     unittest2.main(verbosity=2)
 
